@@ -180,15 +180,13 @@ DiscoverObject::DiscoverObject(const QVariantMap &initialProperties)
             const QString distroName = osRelease.name();
             const bool isArch = osRelease.id() == u"arch"_s || osRelease.idLike().contains(u"arch"_s);
             if (!found) {
-                QString errorText =
-                    i18nc("@title %1 is the distro name", "%1 is not configured for installing apps through Discover—only app add-ons", distroName);
-                QString errorExplanation = xi18nc("@info:usagetip %1 is the distro name",
+                QString errorText = i18nc("@title %1 is the name", "%1 is not configured for installing apps through Discover—only app add-ons", distroName);
+                QString errorExplanation = xi18nc("@info:usagetip %2 is the name of the operating system",
                                                   "To use Discover for apps, install your preferred module on the <interface>Settings"
-                                                  "</interface> page, under <interface>Missing Backends</interface>.");
-                QString buttonIcon = QStringLiteral("tools-report-bug");
-                QString buttonText = i18nc("@action:button %1 is the distro name", "Report This Issue to %1", distroName);
-                QString buttonUrl = osRelease.bugReportUrl();
-
+                                                  "</interface> page, under <interface>Missing Backends</interface>."
+                                                  "<nl/><nl/>Please <link url='%1'>report this issue to %2.</link>",
+                                                  osRelease.bugReportUrl(),
+                                                  distroName);
                 if (isArch) {
                     errorExplanation = xi18nc("@info:usagetip %1 is the distro name; in this case it always contains 'Arch Linux'",
                                               "To use Discover for apps, install"
@@ -196,12 +194,9 @@ DiscoverObject::DiscoverObject(const QVariantMap &initialProperties)
                                               " using the <command>pacman</command> package manager.<nl/><nl/>"
                                               " Review <link url='https://archlinux.org/packages/extra/x86_64/discover/'>%1's packaging for Discover</link>",
                                               distroName);
-                    buttonIcon = QString();
-                    buttonText = QString();
-                    buttonUrl = QString();
                 }
 
-                Q_EMIT openErrorPage(errorText, errorExplanation, buttonText, buttonIcon, buttonUrl);
+                Q_EMIT openErrorPage(errorText, errorExplanation, QString(), QString(), QString());
             } else if (hasPackageKit && isArch) {
                 const QString errorText = xi18nc("@info:usagetip %1 is the distro name",
                                                  "Support for managing packages from %1 is incomplete; you may experience any number of problems."
@@ -409,16 +404,15 @@ void DiscoverObject::openApplication(const QUrl &url)
                     showError(i18n("Please make sure Snap support is installed"));
                 } else {
                     const QString errorText = i18n(
-                        "Could not open %1 because it "
-                        "was not found in any available software repositories.",
-                        url.toDisplayString());
-                    const QString errorExplanation = i18n(
-                        "Please report this "
-                        "issue to the packagers of your distribution.");
-                    QString buttonIcon = QStringLiteral("tools-report-bug");
-                    QString buttonText = i18n("Report This Issue");
-                    QString buttonUrl = KOSRelease().bugReportUrl();
-                    Q_EMIT openErrorPage(errorText, errorExplanation, buttonText, buttonIcon, buttonUrl);
+                        "The requested application could not be found "
+                        "in any available software repositories");
+                    const QString errorExplanation = xi18nc("@info %1 is an additional error reference and %3 is the name of the operating system",
+                                                            "(No entry for %1)<nl/><nl/>Please <link url='%2'>report this issue to %3.</link>",
+                                                            url.toDisplayString(),
+                                                            KOSRelease().bugReportUrl(),
+                                                            KOSRelease().name());
+
+                    Q_EMIT openErrorPage(errorText, errorExplanation, QString(), QString(), QString());
                 }
             });
         },
@@ -468,7 +462,7 @@ public:
 
 bool DiscoverObject::quitWhenIdle()
 {
-    if (!ResourcesModel::global()->isBusy()) {
+    if (!isBusy()) {
         return true;
     }
 
@@ -509,9 +503,14 @@ void DiscoverObject::restore()
     }
 }
 
+bool DiscoverObject::isBusy() const
+{
+    return TransactionModel::global()->rowCount() > 0;
+}
+
 void DiscoverObject::reconsiderQuit()
 {
-    if (ResourcesModel::global()->isBusy()) {
+    if (isBusy()) {
         return;
     }
 
@@ -735,5 +734,21 @@ InlineMessage *DiscoverObject::homePageMessage() const
     return m_homePageMessage.get();
 }
 
+int DiscoverObject::sidebarWidth() const
+{
+    KConfigGroup grp(KSharedConfig::openStateConfig(), u"MainWindow"_s);
+    return grp.readEntry(u"sidebarWidth"_s, -1);
+}
+
+void DiscoverObject::setSidebarWidth(int width)
+{
+    if (width == sidebarWidth()) {
+        return;
+    }
+    KConfigGroup grp(KSharedConfig::openStateConfig(), u"MainWindow"_s);
+    grp.writeEntry(u"sidebarWidth"_s, width);
+    Q_EMIT sidebarWidthChanged(width);
+}
+
 #include "DiscoverObject.moc"
 #include "moc_DiscoverObject.cpp"
