@@ -20,7 +20,7 @@ class Updates : public KQuickManagedConfigModule
     Q_OBJECT
     Q_PROPERTY(UpdatesSettings *updatesSettings READ updatesSettings CONSTANT)
     Q_PROPERTY(DiscoverSettings *discoverSettings READ discoverSettings CONSTANT)
-    Q_PROPERTY(bool isRpmOstree READ isRpmOstree CONSTANT)
+    Q_PROPERTY(bool mandatoryRebootAfterUpdate READ mandatoryRebootAfterUpdate CONSTANT)
 
 public:
     explicit Updates(QObject *parent, const KPluginMetaData &data);
@@ -28,10 +28,10 @@ public:
     UpdatesSettings *updatesSettings() const;
     DiscoverSettings *discoverSettings() const;
 
-    /* Returns true if we're running on an rpm-ostree managed systems. Used to
-     * show/hide PackageKit specific settings and show/hide rpm-ostree specific
-     * settings only on systems where those are relevant.*/
-    bool isRpmOstree() const;
+    /* Returns true if we're running on a system that needs rebooting after updating.
+     * It is used to hide the setting asking the user when to apply the updates
+     * because it's mandatory at times.*/
+    bool mandatoryRebootAfterUpdate() const;
 
 private:
     UpdatesData *const m_data;
