@@ -4,22 +4,17 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef FLATPAKFETCHDATAJOB_H
-#define FLATPAKFETCHDATAJOB_H
+#pragma once
 
-#include <QByteArray>
 #include "flatpak-helper.h"
+#include <QByteArray>
 #include <glib.h>
 
 class FlatpakResource;
 
 namespace FlatpakRunnables
 {
-    FlatpakRemoteRef* findRemoteRef(FlatpakResource *app, GCancellable* cancellable);
+FlatpakRemoteRef *findRemoteRef(FlatpakResource *app, GCancellable *cancellable);
 
-    QByteArray fetchMetadata(FlatpakResource *app, GCancellable* cancellable);
+QByteArray fetchMetadata(FlatpakResource *app, GCancellable *cancellable);
 }
-
-#endif // FLATPAKFETCHDATAJOB_H
-
-
