@@ -4,8 +4,7 @@
  *
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
-#ifndef FLATPAKNOTIFIER_H
-#define FLATPAKNOTIFIER_H
+#pragma once
 
 #include <BackendNotifierModule.h>
 #include <functional>
@@ -15,7 +14,7 @@
 class FlatpakNotifier : public BackendNotifierModule
 {
     Q_OBJECT
-    Q_PLUGIN_METADATA(IID "org.kde.discover.BackendNotifierModule")
+    Q_PLUGIN_METADATA(IID DISCOVER_NOTIFIER_IID)
     Q_INTERFACES(BackendNotifierModule)
 public:
     explicit FlatpakNotifier(QObject *parent = nullptr);
@@ -52,5 +51,3 @@ public:
     GCancellable *const m_cancellable;
     bool m_lastHasUpdates = false;
 };
-
-#endif
