@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef LOCALFILEPKRESOURCE_H
-#define LOCALFILEPKRESOURCE_H
+#pragma once
 
 #include "PackageKitResource.h"
 
@@ -18,11 +17,7 @@ public:
     QString name() const override;
     QString comment() override;
 
-    AbstractResource::State state() override
-    {
-        return m_state;
-    }
-    int size() override;
+    quint64 size() override;
     QString origin() const override;
     void fetchDetails() override;
     bool canExecute() const override
@@ -35,13 +30,10 @@ public:
         return origin();
     }
 
-    void setDetails(const PackageKit::Details &details);
-    void setState(AbstractResource::State state);
+    void resolve(const PackageKit::Details &inDetails);
 
 private:
     AbstractResource::State m_state = AbstractResource::Broken;
     QUrl m_path;
     QString m_exec;
 };
-
-#endif // LOCALFILEPKRESOURCE_H
