@@ -237,9 +237,9 @@ void PackageKitResource::addPackageId(PackageKit::Transaction::Info info, const
     Q_EMIT versionsChanged();
 }
 
-QStringList PackageKitResource::categories()
+bool PackageKitResource::hasCategory(const QString & /*category*/) const
 {
-    return {QStringLiteral("Unknown")};
+    return false;
 }
 
 AbstractResource::Type PackageKitResource::type() const
@@ -286,9 +286,7 @@ void PackageKitResource::setDetails(const PackageKit::Details &details)
             Q_EMIT stateChanged();
         }
 
-        if (!backend()->isFetching()) {
-            Q_EMIT backend()->resourcesChanged(this, {"size", "homepage", "license"});
-        }
+        Q_EMIT backend()->resourcesChanged(this, {"size", "homepage", "license"});
 
         if (oldSize != uint(size())) {
             Q_EMIT sizeChanged();
@@ -355,6 +353,11 @@ static QStringList urlToLinks(const QStringList &urls)
     return ret;
 }
 
+QString PackageKitResource::verifiedMessage() const
+{
+    return i18n("Software verified by %1", displayOrigin());
+}
+
 bool PackageKitResource::containsPackageId(const QString &pkgid) const
 {
     return kContains(m_packages, [pkgid](const auto &x) {
