@@ -6,7 +6,6 @@
  */
 
 #include "RpmOstreeBackend.h"
-#include "RpmOstreeSourcesBackend.h"
 
 #include "Category/Category.h"
 #include "Transaction/TransactionModel.h"
@@ -43,10 +42,6 @@ RpmOstreeBackend::RpmOstreeBackend(QObject *parent)
         return;
     }
 
-    // List configured remotes and display them in the settings page.
-    // We can do this early as this does not depend on the rpm-ostree daemon.
-    SourcesModel::global()->addSourcesBackend(new RpmOstreeSourcesBackend(this));
-
     // Register DBus types
     qDBusRegisterMetaType<QList<QVariantMap>>();
 
@@ -253,6 +248,11 @@ void RpmOstreeBackend::checkForUpdates()
         return;
     }
 
+    if (m_currentlyBootedDeployment->isLocalOCI()) {
+        qCInfo(RPMOSTREE_LOG) << "Ignoring update checks for local OCI transports";
+        return;
+    }
+
     // Do not start a transaction if there is already one in-progress (likely externaly started)
     if (hasExternalTransaction()) {
         qCInfo(RPMOSTREE_LOG) << "Not checking for updates while a transaction is in progress";
@@ -432,10 +432,21 @@ bool RpmOstreeBackend::isValid() const
     return QFile::exists(QStringLiteral("/run/ostree-booted"));
 }
 
+// We only support updating the operating system with this backend. We notably
+// don't support installing applications (i.e. package layering).
 ResultsStream *RpmOstreeBackend::search(const AbstractResourcesBackend::Filters &filter)
 {
+    qCDebug(RPMOSTREE_LOG) << "search: with filter:" << filter;
+
     // Skip the search if we're looking into a Category, but not the "Operating System" category
     if (filter.category && filter.category->untranslatedName() != QLatin1String("Operating System")) {
+        qCDebug(RPMOSTREE_LOG) << "search: skipping, non OS category";
+        return new ResultsStream(QStringLiteral("rpm-ostree-empty"), {});
+    }
+
+    // Skip the search if we're looking at the page for a specific application
+    if (filter.resourceUrl.scheme() == QLatin1String("appstream")) {
+        qCDebug(RPMOSTREE_LOG) << "search: skipping, appstream";
         return new ResultsStream(QStringLiteral("rpm-ostree-empty"), {});
     }
 
@@ -450,13 +461,15 @@ ResultsStream *RpmOstreeBackend::search(const AbstractResourcesBackend::Filters
         }
         // Skip if the search field is not empty and neither the name, description or version matches
         if (!keyword.isEmpty()) {
-            if (!r->name().contains(keyword) && !r->longDescription().contains(keyword) && !r->installedVersion().contains(keyword)) {
+            if (!r->name().contains(keyword, Qt::CaseInsensitive) && !r->longDescription().contains(keyword, Qt::CaseInsensitive)
+                && !r->installedVersion().contains(keyword, Qt::CaseInsensitive)) {
                 continue;
             }
         }
         // Add the ressources to the search filter
         res << r;
     }
+    qCDebug(RPMOSTREE_LOG) << "search: found deployments" << res;
     return new ResultsStream(QStringLiteral("rpm-ostree"), res);
 }
 
